@@ -2,3 +2,6 @@ NANO_ID_ALPHABET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvw
 NANO_URLSAFE_ALPHABET = "0123456789abcdefghijklmnopqrstuvwxyz-_"
 NANO_MACHINE_ALPHABET = "0123456789abcdefghijklmnopqrstuvwxyz"
 JUPCTL_CONF = "jupctl.conf"
+JUP_DNS_KEY = "JUP_DNS_KEY"
+JUP_COMPUTE_KEY = "JUP_COMPUTE_KEY"
+GOOGLE_AUTH_ENV = "GOOGLE_APPLICATION_CREDENTIALS"
