@@ -1,8 +1,9 @@
 import asyncio
+import math
+import os
 from importlib import import_module
 from pathlib import Path
 from typing import Any, Dict
-import os
 
 import tomli
 import tomli_w
@@ -52,3 +53,12 @@ def read_toml(fpath) -> Dict[Any, Any]:
         data = tomli.loads(f.read())
         return data
 
+
+def convert_size(size_bytes):
+    if size_bytes == 0:
+        return "0B"
+    size_name = ("B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
+    i = int(math.floor(math.log(size_bytes, 1024)))
+    p = math.pow(1024, i)
+    s = round(size_bytes / p, 2)
+    return "%s %s" % (s, size_name[i])
